@@ -1,5 +1,6 @@
 use crate::{
-    modules::{HttpFinding, HttpModule, Module},
+    modules::{HttpModule, Module, ModuleName, ModuleVersion},
+    report::{Finding, ModuleResult, Severity},
     Error,
 };
 use async_trait::async_trait;
@@ -14,22 +15,30 @@ impl EtcdUnauthenticatedAccess {
 }
 
 impl Module for EtcdUnauthenticatedAccess {
-    fn name(&self) -> String {
-        String::from("http/etc_unauthenticated_access")
+    fn name(&self) -> ModuleName {
+        ModuleName::HttpEtcdUnauthenticatedAccess
     }
 
     fn description(&self) -> String {
         String::from("Check for CoreOS' etcd Unauthenticated Access")
     }
+
+    fn version(&self) -> ModuleVersion {
+        ModuleVersion(1, 0, 0)
+    }
+
+    fn is_aggressive(&self) -> bool {
+        false
+    }
+
+    fn severity(&self) -> Severity {
+        Severity::High
+    }
 }
 
 #[async_trait]
 impl HttpModule for EtcdUnauthenticatedAccess {
-    async fn scan(
-        &self,
-        http_client: &Client,
-        endpoint: &str,
-    ) -> Result<Option<HttpFinding>, Error> {
+    async fn scan(&self, http_client: &Client, endpoint: &str) -> Result<Option<Finding>, Error> {
         let url = format!("{}/version", &endpoint);
         let res = http_client.get(&url).send().await?;
 
@@ -42,7 +51,12 @@ impl HttpModule for EtcdUnauthenticatedAccess {
             && body.contains(r#""etcdcluster""#)
             && body.chars().count() < 200
         {
-            return Ok(Some(HttpFinding::EtcdUnauthenticatedAccess(url)));
+            return Ok(Some(Finding {
+                module: self.name(),
+                module_version: self.version(),
+                severity: self.severity(),
+                result: ModuleResult::Url(url),
+            }));
         }
 
         Ok(None)
